@@ -18,6 +18,7 @@ log = logging.getLogger('dogstatsd')
 
 
 class DogStatsd(object):
+    OK, WARNING, CRITICAL, UNKNOWN = (0, 1, 2, 3)
 
     def __init__(self, host='localhost', port=8125, max_buffer_size = 50):
         """
@@ -196,6 +197,9 @@ class DogStatsd(object):
     def _escape_event_content(self, string):
         return string.replace('\n', '\\n')
 
+    def _escape_service_check_message(self, string):
+        return string.replace('\n', '\\n').replace('m:', 'm\:')
+
     def event(self, title, text, alert_type=None, aggregation_key=None,
               source_type_name=None, date_happened=None, priority=None,
               tags=None, hostname=None):
@@ -233,5 +237,30 @@ class DogStatsd(object):
         except Exception:
             log.exception(u'Error submitting event "%s"' % title)
 
+    def service_check(self, check_name, status, tags=None, timestamp=None,
+                      hostname=None, message=None):
+        """
+        Send a service check run.
+
+        >>> statsd.service_check('my_service.check_name', DogStatsd.WARNING)
+        """
+        message = self._escape_service_check_message(message) if message is not None else ''
+
+        string = u'_sc|{0}|{1}'.format(check_name, status)
+
+        if timestamp:
+            string = u'{0}|d:{1}'.format(string, timestamp)
+        if hostname:
+            string = u'{0}|h:{1}'.format(string, hostname)
+        if tags:
+            string = u'{0}|#{1}'.format(string, ','.join(tags))
+        if message:
+            string = u'{0}|m:{1}'.format(string, message)
+
+        try:
+            self.socket.send(string.encode(self.encoding))
+        except Exception:
+            log.exception(u'Error submitting service check "{0}"'.format(check_name))
+
 
 statsd = DogStatsd()
